#!/usr/bin/ksh

# 5724-J08, 5724-I63, 5724-H88, 5655-N01, 5733-W61 (C) COPYRIGHT International Business Machines Corp. 1997, 2006
# All Rights Reserved * Licensed Materials - Property of IBM                                     

# DESCRIPTION:
#    Script file used to easily configure WebSphere Plug-in for IHS.

 PLUGIN_HOME=
 OS_NAME=
 IHS_CONF=
 IHS_ADMIN_USERGROUP=
 PLUGIN_CFG_XML=
 INSTALL_ARCH="32"
 PLUGIN_INSTALL_TYPE="remote"
 WEBSERVER_NAME="webserver1"
 WAS_HOSTNAME="localhost"

printUsage()
{
        echo ""
        echo ""
        echo "Usage: ConfigureIHSPlugin.sh"
        echo "      -plugin.home <pluginInstallRoot>  "
        echo "      -plugin.config.xml <pluginConfigFile>  "
        echo "      -ihs.conf.file <confFile>   >"
        echo "      -ihs.admin.usergroup <userGroup>   >"
        echo "      -operating.system <operatingSystem>  " 
        echo "    [ -operating.system.arch <arch> ] "
        echo "    [ -WAS.webserver.name <webserverName>]"
        echo "    [ -WAS.host.name <wasHostName>]"        
        echo "    [ -help | -? ]"
        echo " "
        echo "Where:"
        echo "    \"plugin.home\" is the plugin install root"
        echo "    \"plugin.config.xml\" is the full path of plugin-config.xml file"
        echo "    \"ihs.conf.file\" is the full path name of the httpd.conf"
        echo "    \"ihs.admin.usergroup\" is the user group of IHS Admin server" 
        echo "    \"operating.system\" is the name of the operating system" 
        echo "        Possible values are: Linux|AIX|HP-UX|SunOS|ZOS"
        echo "    \"operating.system.arch\" is the architecture of the operating system"
        echo "        Possible values are: 32|64. Default value is 32"
	echo "    \"WAS.webserver.name\" is the name of the webserver as defined "
        echo "        in WebSphere admin console. Default is webserver1"
	echo "    \"WAS.host.name\" is the host name of the WebSphere"
        echo " "
        echo "IHS Example: "
        echo "    ConfigureIHSPlugin.sh -plugin.home /opt/IBM/WebSphere/Plugins"
        echo "           -plugin.config.xml /opt/IBM/WebSphere/Plugins/config/webserver1/plugin-cfg.xml"
        echo "           -ihs.conf.file /opt/IHS/conf/httpd.conf"
        echo "           -ihs.admin.usergroup ihsadmin" 
        echo "           -operating.system AIX  "
        echo "           -operating.system.arch 64"
        echo "           -WAS.webserver.name webserver2"
        echo "           -WAS.host.name localhost"
        echo " "
        echo " "

        exit 0
}

printError()
{
        echo "ERROR: $1"
        printUsage
}

if [ $# -eq 0 ] ; then
   printUsage
fi

 while [ $# -gt 0 ]; do
    case $1 in
              -help|-?) printUsage 
                        exit 0                
                        ;;
          -plugin.home) shift
                        PLUGIN_HOME="$1"
                        ;;
     -operating.system) shift
                        OS_NAME="$1"
                        ;;
        -ihs.conf.file) shift
                        IHS_CONF="$1"
                        ;;
        -ihs.admin.usergroup) shift
                        IHS_ADMIN_USERGROUP="$1"
                        ;;
    -plugin.config.xml) shift
                        PLUGIN_CFG_XML="$1"
                        ;;
   -WAS.webserver.name) shift
                        WEBSERVER_NAME="$1"
                        ;;
        -WAS.host.name) shift
                        WAS_HOSTNAME="$1"
                        ;;
 -operating.system.arch) shift
                         INSTALL_ARCH="$1"
                        ;;
                     -*) echo "Unsupported option"
                         echo "$1"
                         printUsage 
                         exit 0                
                         ;;
   esac
   shift
done

if [ $OS_NAME = ZOS ] ; then
    IHS_ADMIN_USERGROUP=
    INSTALL_ARCH="64"
fi

${PLUGIN_HOME}/bin/setupCmdLine.sh
${PLUGIN_HOME}/bin/ws_ant.sh -f ${PLUGIN_HOME}/properties/version/nif/config/install/99SBootStrapPluginsIHS.ant \
                                     -DPLUGIN_HOME=${PLUGIN_HOME} -DOS_NAME=${OS_NAME} \
                                     -DIHS_CONF=${IHS_CONF} -DWAS_PLUGIN_CFG_XML=${PLUGIN_CFG_XML} \
                                     -DINSTALL_ARCH=${INSTALL_ARCH} -DPLUGIN_INSTALL_TYPE=${PLUGIN_INSTALL_TYPE} \
  			             -DWEBSERVER_NAME=${WEBSERVER_NAME} -DWEBSERVER_TYPE=IHS \
                                     -DIHS_ADMIN_USERGROUP=${IHS_ADMIN_USERGROUP} -DWAS_HOSTNAME=${WAS_HOSTNAME}

